[![Build Status](https://api.travis-ci.org/real-easypy/easypy.svg?branch=master)](https://travis-ci.org/real-easypy/easypy)
[![Documentation](https://img.shields.io/badge/api-sphinx-blue.svg)](https://real-easypy.github.io/easypy/)

# easypy
easypy makes python even easier!

Many boiler-plate patterns are reduced to simple yet richly featured constructs:
- concurrency - running asynchronous code easily and manageably
- resiliency - retrying or swallowing exceptions
- synchronization - poll-and-wait for long-running process to complete
- collections - filter and choose objects using keywords and predicates

In addition, there are humanization modules that help both code and logs more user-friendly
- represting data-size and time units
- randomizing strings
- coloring and structured logging
- tokens

... And much more!

Contributers please read [CONTRIBUTING.md](CONTRIBUTING.md).
